Learn R Programming

kStatistics (version 1.0)

mCoeff: Multiplicity in a multiset

Description

Generates the instances of an element in a multiset.

Usage

mCoeff( v, L )

Arguments

v

block array to search

L

list of two-dimensional arrays: in the first there is a vector and in the second the multiplicative value to be returned

Value

float

multiplicity of the researched item

Details

This function is useful in the construction of kStatistics. Compute how many times an element is in a multiset, that is its multiplicity.

References

E. Di Nardo, G. Guarino and D. Senato (2008) An unifying framework for k-statistics, polykays and their generalizations. Bernoulli. Vol. 14(2), 440-468. (download from http://www.elviradinardo.it/lavori1.html)

See Also

mkmSet, umSet, countP, nStirling2, intPart, df

Examples

Run this code
# NOT RUN {
L1 <- mkmSet(c(3))   
# generates [[1,1,1],1], [[1,2],3], [[3],1]
mCoeff( c(1,2), L1)  
# returns 3 that is the istance of [1,2] in L1
 
# }

Run the code above in your browser using DataLab